Class: Aws::WorkSpacesThinClient::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkSpacesThinClient::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspacesthinclient/client.rb,
sig/client.rbs
Overview
An API client for WorkSpacesThinClient. To construct a client, you need to configure a :region and :credentials.
client = Aws::WorkSpacesThinClient::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateEnvironmentResponseSuccess, _DeleteDeviceResponseSuccess, _DeleteEnvironmentResponseSuccess, _DeregisterDeviceResponseSuccess, _GetDeviceResponseSuccess, _GetEnvironmentResponseSuccess, _GetSoftwareSetResponseSuccess, _ListDevicesResponseSuccess, _ListEnvironmentsResponseSuccess, _ListSoftwareSetsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDeviceResponseSuccess, _UpdateEnvironmentResponseSuccess, _UpdateSoftwareSetResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an environment for your thin client devices.
-
#delete_device(params = {}) ⇒ Struct
Deletes a thin client device.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
-
#deregister_device(params = {}) ⇒ Struct
Deregisters a thin client device.
-
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Returns information for a thin client device.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns information for an environment.
-
#get_software_set(params = {}) ⇒ Types::GetSoftwareSetResponse
Returns information for a software set.
-
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of thin client devices.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Returns a list of environments.
-
#list_software_sets(params = {}) ⇒ Types::ListSoftwareSetsResponse
Returns a list of software sets.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates a thin client device.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates an environment.
-
#update_software_set(params = {}) ⇒ Struct
Updates a software set.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1350 1351 1352 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1350 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1353 1354 1355 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1353 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1323 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkSpacesThinClient') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspacesthinclient' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an environment for your thin client devices.
86 |
# File 'sig/client.rbs', line 86
def create_environment: (
|
#delete_device(params = {}) ⇒ Struct
Deletes a thin client device.
105 |
# File 'sig/client.rbs', line 105
def delete_device: (
|
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
115 |
# File 'sig/client.rbs', line 115
def delete_environment: (
|
#deregister_device(params = {}) ⇒ Struct
Deregisters a thin client device.
125 |
# File 'sig/client.rbs', line 125
def deregister_device: (
|
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Returns information for a thin client device.
137 |
# File 'sig/client.rbs', line 137
def get_device: (
|
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns information for an environment.
147 |
# File 'sig/client.rbs', line 147
def get_environment: (
|
#get_software_set(params = {}) ⇒ Types::GetSoftwareSetResponse
Returns information for a software set.
157 |
# File 'sig/client.rbs', line 157
def get_software_set: (
|
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of thin client devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
168 |
# File 'sig/client.rbs', line 168
def list_devices: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Returns a list of environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
180 |
# File 'sig/client.rbs', line 180
def list_environments: (
|
#list_software_sets(params = {}) ⇒ Types::ListSoftwareSetsResponse
Returns a list of software sets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
192 |
# File 'sig/client.rbs', line 192
def list_software_sets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
203 |
# File 'sig/client.rbs', line 203
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
212 |
# File 'sig/client.rbs', line 212
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
222 |
# File 'sig/client.rbs', line 222
def untag_resource: (
|
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates a thin client device.
233 |
# File 'sig/client.rbs', line 233
def update_device: (
|
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates an environment.
246 |
# File 'sig/client.rbs', line 246
def update_environment: (
|
#update_software_set(params = {}) ⇒ Struct
Updates a software set.
263 |
# File 'sig/client.rbs', line 263
def update_software_set: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1343 1344 1345 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1343 def waiter_names [] end |