Class: Aws::WorkSpacesThinClient::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkSpacesThinClient::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspacesthinclient/client.rb
Overview
An API client for WorkSpacesThinClient. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::WorkSpacesThinClient::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an environment for your thin client devices.
-
#delete_device(params = {}) ⇒ Struct
Deletes a thin client device.
-
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
-
#deregister_device(params = {}) ⇒ Struct
Deregisters a thin client device.
-
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Returns information for a thin client device.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns information for an environment.
-
#get_software_set(params = {}) ⇒ Types::GetSoftwareSetResponse
Returns information for a software set.
-
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of thin client devices.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Returns a list of environments.
-
#list_software_sets(params = {}) ⇒ Types::ListSoftwareSetsResponse
Returns a list of software sets.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
-
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates a thin client device.
-
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates an environment.
-
#update_software_set(params = {}) ⇒ Struct
Updates a software set.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1350 1351 1352 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1350 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1353 1354 1355 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1353 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1323 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkSpacesThinClient') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspacesthinclient' context[:gem_version] = '1.45.0' Seahorse::Client::Request.new(handlers, context) end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an environment for your thin client devices.
597 598 599 600 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 597 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#delete_device(params = {}) ⇒ Struct
Deletes a thin client device.
642 643 644 645 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 642 def delete_device(params = {}, = {}) req = build_request(:delete_device, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Struct
Deletes an environment.
687 688 689 690 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 687 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#deregister_device(params = {}) ⇒ Struct
Deregisters a thin client device.
736 737 738 739 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 736 def deregister_device(params = {}, = {}) req = build_request(:deregister_device, params) req.send_request() end |
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Returns information for a thin client device.
784 785 786 787 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 784 def get_device(params = {}, = {}) req = build_request(:get_device, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Returns information for an environment.
838 839 840 841 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 838 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_software_set(params = {}) ⇒ Types::GetSoftwareSetResponse
Returns information for a software set.
874 875 876 877 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 874 def get_software_set(params = {}, = {}) req = build_request(:get_software_set, params) req.send_request() end |
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of thin client devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
935 936 937 938 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 935 def list_devices(params = {}, = {}) req = build_request(:list_devices, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Returns a list of environments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1001 1002 1003 1004 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1001 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_software_sets(params = {}) ⇒ Types::ListSoftwareSetsResponse
Returns a list of software sets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1052 1053 1054 1055 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1052 def list_software_sets(params = {}, = {}) req = build_request(:list_software_sets, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
1082 1083 1084 1085 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1082 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
1111 1112 1113 1114 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1111 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or tags from a resource.
1138 1139 1140 1141 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1138 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_device(params = {}) ⇒ Types::UpdateDeviceResponse
Updates a thin client device.
1194 1195 1196 1197 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1194 def update_device(params = {}, = {}) req = build_request(:update_device, params) req.send_request() end |
#update_environment(params = {}) ⇒ Types::UpdateEnvironmentResponse
Updates an environment.
1288 1289 1290 1291 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1288 def update_environment(params = {}, = {}) req = build_request(:update_environment, params) req.send_request() end |
#update_software_set(params = {}) ⇒ Struct
Updates a software set.
1314 1315 1316 1317 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1314 def update_software_set(params = {}, = {}) req = build_request(:update_software_set, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1343 1344 1345 |
# File 'lib/aws-sdk-workspacesthinclient/client.rb', line 1343 def waiter_names [] end |